Quantum Identity Authentiation Library
======================================

A library implementing different Quantum Identity Authentication Protocols using SimulaQron.

Install library using `python setup.py install` and the required packages using `pip install -r requirements.txt` command.

Start SimulaQron server using `simulaqron start`.

Check out the Zawadzki Protocol by going to qAuth/examples/zwdz and run `sh run.sh`.

Official docs at : https://qauth.readthedocs.io/en/latest/